@@ -9,7 +9,7 @@ class view(object):
        under the 3D view. If you have a predefined cutom view, 
        you can use the predefined commands in icn3dpy.
     '''
-    def __init__(self,width=640,height=480,q="",pdb="",para="",command="",v=""):
+    def __init__(self,width=640,height=480,q="",para="",command="",v=""):
         '''Create a iCn3D view.
             width -- width of 3D canvas in pixels
             height -- height of 3D canvas in pixels
@@ -97,7 +97,7 @@ css1
         para = para.replace("&", ",")
         command = unquote(command)
 
-        self.startjs += 'cfg = {divid: "%s", pdb: "%s", %swidth: "%spx", height: "%spx", mobilemenu: 1, notebook: 1, command: \'%s\', %s};\n' % (divid, pdb, inputid, width, height, command, para)
+        self.startjs += 'cfg = {divid: "%s", %swidth: "%spx", height: "%spx", mobilemenu: 1, notebook: 1, command: \'%s\', %s};\n' % (divid, inputid, width, height, command, para)
 
         self.startjs += 'viewerUNIQUEID = new icn3d.iCn3DUI(cfg);\n'
         
